@@ -8,3 +8,6 @@ from frostaura.data_access.public_asset_data_access__yahoo_finance import YahooF
 
 from frostaura.data_access.personal_asset_data_access import IPersonalAssetDataAccess
 from frostaura.data_access.personal_asset_data_access__easy_equities import EasyEquitiesPersonalAssetDataAccess
+
+from frostaura.data_access.notifications_data_access import INotificationsDataAccess
+from frostaura.data_access.notifications_data_access__telegram import TelegramNotificationsDataAccess
